@@ -47,6 +47,8 @@ static const char notice[] = I18N_NOOP("(c) 1998-2000, Matthias Kiefer\n"
 
 int main(int argc, char* argv[])
 {
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("ksnakeduel");
